==> hs-test-framework-0.4.0_2.tbz: lib/ghc-7.0.3/cabal/test-framework-0.4.0/register.sh <==
#!/bin/sh
echo 'name: test-framework
version: 0.4.0
id: test-framework-0.4.0-e1452e3d765a886277fc89a3e7d3ed50

license: BSD3
copyright:
maintainer: Max Bolingbroke <batterseapower@hotmail.com>
stability:
homepage: http://batterseapower.github.com/test-framework/
package-url:
description: Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
             parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
             command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules: Test.Framework Test.Framework.Options
                 Test.Framework.Providers.API Test.Framework.Runners.Console
                 Test.Framework.Runners.Options Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics
                Test.Framework.Runners.TestPattern
                Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/test-framework-0.4.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/test-framework-0.4.0
              /usr/local/lib
hs-libraries: HStest-framework-0.4.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: ansi-terminal-0.5.5-572a1d0154fb2632bb4e9431adf0cdb1
         ansi-wl-pprint-0.6.3-d620065cb24d17cc39b2333f2d3cfd7c
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
         hostname-1.0-c77e46815836076c00f81c07da3767a7
         old-locale-1.0.0.2-cc522edd16b73a70b897598c5f5d20c7
         random-1.0.0.3-15ae8b1458485ee9647f74174e442c33
         regex-posix-0.94.4-98825960cd448bd99a4f826bc3a7f321
         time-1.2.0.3-4f1bed38bdf37d398ba8f4311cbdac4a
         xml-1.3.9-7707730d5cf7e473c9c13f16bcc4329e
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/test-framework-0.4.0/html/test-framework.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/test-framework-0.4.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-test-framework-0.5.tbz: lib/ghc-7.0.4/cabal/test-framework-0.5/register.sh <==
#!/bin/sh
echo 'name: test-framework
version: 0.5
id: test-framework-0.5-32f5c4d42a78bcbd6ddd6542dc0e8790

license: BSD3
copyright:
maintainer: Max Bolingbroke <batterseapower@hotmail.com>
stability:
homepage: http://batterseapower.github.com/test-framework/
package-url:
description: Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
             parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
             command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules: Test.Framework Test.Framework.Options
                 Test.Framework.Providers.API Test.Framework.Runners.Console
                 Test.Framework.Runners.Options Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics
                Test.Framework.Runners.TestPattern
                Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/test-framework-0.5
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/test-framework-0.5
              /usr/local/lib
hs-libraries: HStest-framework-0.5
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: ansi-terminal-0.5.5-572a1d0154fb2632bb4e9431adf0cdb1
         ansi-wl-pprint-0.6.4-4dd8b78a65c1aa58f8c1d58cd88817f0
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
         hostname-1.0-5bb472a8c4e44fdb66860bfca220e074
         old-locale-1.0.0.2-6e2a3c0744e8cf4e0ac2d4e58659f7b5
         random-1.0.0.3-57524486875e0c4c260dd22788921013
         regex-posix-0.95.1-c7ed376b0544c471f930ad8f770c3b62
         time-1.2.0.3-57ebba2cc05370f666b7eceba5e468a9
         xml-1.3.12-021e9034e0c8089246f869aa0e3f0719
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/test-framework-0.5/html/test-framework.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/test-framework-0.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
